Skip to main contentModule session
Source - cancel_prompt
- Cancel a running prompt by sending SIGTERM to the active process.
- session_status
- Show the status of the current session, including whether a prompt is running.
- sessions_close
- Close a session by setting its
closed flag to true. - sessions_history
- Show conversation history for a session.
- sessions_list
- List all session files, optionally filtered by agent and cwd.
- sessions_new
- Create a new session record and persist it to disk.
- sessions_show
- Show detailed information about a session.
- set_config
- Set a session config option by sending a request to the queue owner via IPC.
- set_mode
- Set the session mode by sending a request to the queue owner via IPC.