pub async fn set_mode(
agent: &str,
cwd: &str,
name: Option<&str>,
mode: &str,
) -> Result<()>Expand description
Set the session mode by sending a request to the queue owner via IPC.
Requires an active session with a running queue owner process.