Module permissions
acp_cli
0.2.0
Module permissions
Module Items
Enums
Functions
In acp_
cli::
client
acp_cli
::
client
Module
permissions
Enums

Permission
Mode
Functions

is_
read_
only_
tool
Returns true if the tool name corresponds to a read-only operation.
resolve_
permission
Resolve a permission request based on the current permission mode.