Skip to main contentModule ipc
Source - cleanup_socket
- Remove the socket file for a session (best-effort cleanup).
- connect_ipc
- Connect to an existing IPC server for the given session.
- recv_message
- Read one message from a Unix stream.
- send_message
- Send a message over a Unix stream as a single JSON line.
- socket_path
- Return the Unix socket path for a given session key.
Uses first 12 hex chars of the key to stay within macOS SUN_LEN limit (~104 bytes).
- start_ipc_server
- Start an IPC server on a Unix socket.