socket_path

Function socket_path 

pub fn socket_path(session_key: &str) -> PathBuf
Return the Unix socket path for a given session key. Uses first 12 hex chars of the key to stay within macOS SUN_LEN limit (~104 bytes).