Module pid

Module pid 

Functions

read_pid
Read the PID from the pid file and check if the process is alive.
remove_pid
Remove the pid file for a session key.
write_pid
Write the current process PID to the pid file for a session key.