find_session

Function find_session 

pub fn find_session(
    agent: &str,
    cwd: &Path,
    name: &str,
) -> Option<SessionRecord>
Find an existing session record for the given agent, working directory, and name.

Resolves the directory to a git root (if possible), computes the session key, and attempts to load the corresponding session file.