pub async fn set_config(
agent: &str,
cwd: &str,
name: Option<&str>,
key: &str,
value: &str,
) -> Result<()>Expand description
Set a session config option by sending a request to the queue owner via IPC.
Requires an active session with a running queue owner process.