Module pid
acp_cli
0.3.1
Module pid
Module Items
Functions
In acp_
cli::
session
acp_cli
::
session
Module
pid
Functions

read_
pid
Read the PID from the pid file and check if the process is alive.
remove_
pid
Remove the pid file for a session key.
write_
pid
Write the current process PID to the pid file for a session key.